Image

Struct Image 

pub struct Image {
    pub version: u8,
    pub width: u16,
    pub height: u16,
    /* private fields */
}
Struct für die Bilddaten. Enthält eine Versionsnummer, die Breite und Höhe des Bildes, die Bit-Tiefe und die indizierten Bilddaten.

Fields

version: u8width: u16height: u16

Implementations

Source

impl Image

pub fn new(version: u8, width: u16, height: u16, bytes: Vec<u8>) -> Self

Erstellt ein neues Bild. Die Bittiefe wird automatisch ermittelt und auf 4 oder 8 Bit gesetzt. Die Bilddaten müssen in einem Vektor mit der Größe width * height sein.

pub unsafe fn new_unchecked( version: u8, width: u16, height: u16, bits: u8, bytes: Vec<u8>, ) -> Self

Erstellt ein neues Bild ohne Überprüfung der Bittiefe.

Safety

Der Aufrufer muss sicher stellen, dass die Abmessung zu den Bilddaten passt und die Bittiefe korrekt ist.

pub fn bit_depth(&self) -> u8

Die Bit-Tiefe des Bildes. Entweder 4 oder 8 bit.

pub fn bytes(&self) -> &[u8]

Die Bilddaten.

pub fn size(&self) -> usize

Die Abmessungen des Bildes.